/*---------------------------------------------------------------------------*\
| =========                 |                                                 |
| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\    /   O peration     | Version:  1.5                                   |
|   \\  /    A nd           | Web:      http://www.openfoam.org               |
|    \\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/

FoamFile
{
    version         2.0;
    format          ascii;
    class           dictionary;
    object          blockMeshDict;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

// Parametrized test case for the El-Alti Active Flow Control actuator.

//Run using:
//m4 -P blockMeshDict.m4 > blockMeshDict

//m4 definitions:
m4_changecom(//)m4_changequote([,])
m4_define(calc, [m4_esyscmd(perl -e 'use Math::Trig; printf ($1)')])
m4_define(VCOUNT, 0)
m4_define(vlabel, [[// ]Vertex $1 = VCOUNT m4_define($1, VCOUNT)m4_define([VCOUNT], m4_incr(VCOUNT))])

//Mathematical constants:
m4_define(pi, 3.1415926536)

//Geometry
m4_define(boxWidthX,  0.5)
m4_define(boxWidthY,  0.01)
m4_define(slotWidthX,  0.01) //NOTE: slotWidthX < boxWidthX!!!
m4_define(boxHeight,  0.5)
m4_define(slotHeight,  0.002)
m4_define(ambientHeight,  0.5)

//Grid points (integers!):
m4_define(slotCellSize, 0.001) //NOTE: A fraction of slotWidthX
m4_define(slotCellsX, calc(int(slotWidthX/slotCellSize)))
m4_define(outsideSlotCellsX, 40)
m4_define(zABnumberOfCells, 80)
m4_define(zBCnumberOfCells, calc(int(slotHeight/slotCellSize)))
m4_define(zCDnumberOfCells, 80)
m4_define(outsideSlotGradingX, calc(1/15))
m4_define(boxGrading, calc(1/15))
m4_define(ambientGrading, calc(15))

//Plane A:
m4_define(zA, calc(-boxHeight-slotHeight))

//Plane B:
m4_define(zB, calc(-slotHeight))

//Plane C:
m4_define(zC, 0)

//Plane D:
m4_define(zD, ambientHeight)

convertToMeters 1;

vertices
(
//Plane A:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zA) vlabel(A0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zA) vlabel(A1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zA) vlabel(A2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zA) vlabel(A3)
(calc(-boxWidthX/2) calc(boxWidthY/2) zA) vlabel(A4)
(calc(-slotWidthX/2) calc(boxWidthY/2) zA) vlabel(A5)
(calc(slotWidthX/2) calc(boxWidthY/2) zA) vlabel(A6)
(calc(boxWidthX/2) calc(boxWidthY/2) zA) vlabel(A7)

//Plane B:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zB) vlabel(B0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zB) vlabel(B1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zB) vlabel(B2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zB) vlabel(B3)
(calc(-boxWidthX/2) calc(boxWidthY/2) zB) vlabel(B4)
(calc(-slotWidthX/2) calc(boxWidthY/2) zB) vlabel(B5)
(calc(slotWidthX/2) calc(boxWidthY/2) zB) vlabel(B6)
(calc(boxWidthX/2) calc(boxWidthY/2) zB) vlabel(B7)

//Plane C:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zC) vlabel(C0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zC) vlabel(C1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zC) vlabel(C2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zC) vlabel(C3)
(calc(-boxWidthX/2) calc(boxWidthY/2) zC) vlabel(C4)
(calc(-slotWidthX/2) calc(boxWidthY/2) zC) vlabel(C5)
(calc(slotWidthX/2) calc(boxWidthY/2) zC) vlabel(C6)
(calc(boxWidthX/2) calc(boxWidthY/2) zC) vlabel(C7)

//Plane D:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zD) vlabel(D0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zD) vlabel(D1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zD) vlabel(D2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zD) vlabel(D3)
(calc(-boxWidthX/2) calc(boxWidthY/2) zD) vlabel(D4)
(calc(-slotWidthX/2) calc(boxWidthY/2) zD) vlabel(D5)
(calc(slotWidthX/2) calc(boxWidthY/2) zD) vlabel(D6)
(calc(boxWidthX/2) calc(boxWidthY/2) zD) vlabel(D7)
);

// Defining blocks:
blocks
(

    //Blocks between plane A and plane B:
    hex (A0 A1 A5 A4 B0 B1 B5 B4 ) AB
      (outsideSlotCellsX 1 zABnumberOfCells)
      simpleGrading (outsideSlotGradingX 1 boxGrading)
    hex (A1 A2 A6 A5 B1 B2 B6 B5 ) AB
      (slotCellsX 1 zABnumberOfCells)
      simpleGrading (1 1 boxGrading)
    hex (A2 A3 A7 A6 B2 B3 B7 B6 ) AB
      (outsideSlotCellsX 1 zABnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) 1 boxGrading)

    //Blocks between plane B and plane C:
    hex (B1 B2 B6 B5 C1 C2 C6 C5 ) BC
      (slotCellsX 1 zBCnumberOfCells)
      simpleGrading (1 1 1)

    //Blocks between plane C and plane D:
    hex (C0 C1 C5 C4 D0 D1 D5 D4 ) CD
      (outsideSlotCellsX 1 zCDnumberOfCells)
      simpleGrading (outsideSlotGradingX 1 ambientGrading)
    hex (C1 C2 C6 C5 D1 D2 D6 D5 ) CD
      (slotCellsX 1 zCDnumberOfCells)
      simpleGrading (1 1 ambientGrading)
    hex (C2 C3 C7 C6 D2 D3 D7 D6 ) CD
      (outsideSlotCellsX 1 zCDnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) 1 ambientGrading)
);

edges
(
);

// Defining patches:
patches
(
    patch boxBottom
    (
       (A1 A0 A4 A5)
       (A2 A1 A5 A6)
       (A3 A2 A6 A7)
    )
    patch boxSide
    (
       (A3 A7 B7 B3)
       (A4 A0 B0 B4)
    )
    wall boxTop
    (
       (B5 B4 B0 B1)
       (B7 B6 B2 B3)
    )
    wall slotSide
    (
       (B2 B6 C6 C2)
       (B5 B1 C1 C5)
    )
    wall ambientBottom
    (
       (C1 C0 C4 C5)
       (C3 C2 C6 C7)
    )
    patch ambientSide
    (
       (C3 C7 D7 D3)
       (C4 C0 D0 D4)
    )
    patch ambientTop
    (
       (D5 D4 D0 D1)
       (D6 D5 D1 D2)
       (D7 D6 D2 D3)
    )
    empty frontAndBack
    (
       (A0 A1 B1 B0)
       (A1 A2 B2 B1)
       (A2 A3 B3 B2)

       (A7 A6 B6 B7)
       (A6 A5 B5 B6)
       (A5 A4 B4 B5)

       (B1 B2 C2 C1)

       (B6 B5 C5 C6)

       (C0 C1 D1 D0)
       (C1 C2 D2 D1)
       (C2 C3 D3 D2)

       (C7 C6 D6 D7)
       (C6 C5 D5 D6)
       (C5 C4 D4 D5)
    )
);

mergePatchPairs 
(
);

// ************************************************************************* //
